@@ -18,7 +18,7 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 		Project page: http://repo.hu/projects/scconfig
-		Contact via email: scconfig [at] igor2.repo.hu
+		Contact (email and IRC): http://igor2.repo.hu/contact.html
 */
 
 #include <stdlib.h>
@@ -180,8 +180,8 @@ int find_posix_posix_spawn(const char *name, int logdepth, int fatal)
 		NL "{"
 		NL "	pid_t pid;"
 		NL "	int st;"
-		NL "	char *args[] = { \"sh\", \"-c\", \"echo OK\", NULL };"
-		NL "	if (posix_spawnp(&pid, args[0], NULL, NULL, args, environ) != 0)"
+		NL "	char *args[] = { \"sh\", \"-c\", \"echo OK\", (char *)0 };"
+		NL "	if (posix_spawnp(&pid, args[0], (void *)0, (void *)0, args, environ) != 0)"
 		NL "		return 1;"
 		NL "	if (my_wait(&st) == -1)"
 		NL "		return 1;"
