@@ -434,6 +434,15 @@ void pcb_buffer_rotate90(pcb_buffer_t *Buffer, unsigned int Number)
 			rnd_rtree_insert(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 	}
 	PCB_ENDALL_LOOP;
+	PCB_GFX_ALL_LOOP(Buffer->Data);
+	{
+		if (layer->gfx_tree != NULL)
+			rnd_rtree_delete(layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
+		pcb_gfx_rotate90(gfx, Buffer->X, Buffer->Y, Number);
+		if (layer->gfx_tree != NULL)
+			rnd_rtree_insert(layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
+	}
+	PCB_ENDALL_LOOP;
 
 	/* finally the origin and the bounding box */
 	RND_COORD_ROTATE90(Buffer->X, Buffer->Y, Buffer->X, Buffer->Y, Number);
@@ -486,6 +495,11 @@ void pcb_buffer_rotate(pcb_buffer_t *Buffer, rnd_angle_t angle)
 		pcb_poly_rotate(layer, polygon, Buffer->X, Buffer->Y, cosa, sina);
 	}
 	PCB_ENDALL_LOOP;
+	PCB_GFX_ALL_LOOP(Buffer->Data);
+	{
+		pcb_gfx_rotate(layer, gfx, Buffer->X, Buffer->Y, cosa, sina, angle);
+	}
+	PCB_ENDALL_LOOP;
 
 	pcb_set_buffer_bbox(Buffer);
 	pcb_undo_unfreeze_add();
