@@ -40,7 +40,6 @@
 #include "obj_rat_list.h"
 #include "obj_subc_list.h"
 #include "obj_pstk_list.h"
-#include <librnd/poly/rtree2_compat.h>
 #include "vtpadstack.h"
 #include <genht/htip.h>
 
@@ -131,10 +130,11 @@ void pcb_data_free(pcb_data_t *data);
 
 rnd_bool pcb_data_is_empty(pcb_data_t *);
 
-/* gets minimum and maximum coordinates
- * returns NULL if layout is empty */
-rnd_box_t *pcb_data_bbox(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_floaters);
-rnd_box_t *pcb_data_bbox_naked(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_floaters);
+/* Gets minimum and maximum coordinates; returns NULL if data is empty;
+   If ignore_floaters_and_aux is true, floaters and aux layer objects
+   (unity vectors) are not considered for the bbox. */
+rnd_box_t *pcb_data_bbox(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_floaters_and_aux);
+rnd_box_t *pcb_data_bbox_naked(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_floaters_and_aux);
 
 /* Make sure all layers of data has their .parent field pointing to the data */
 void pcb_data_set_layer_parents(pcb_data_t *data);
@@ -195,10 +195,10 @@ void pcb_data_clip_polys(pcb_data_t *data);
 
 
 /* rsearch on all trees matching types of data */
-rnd_r_dir_t pcb_data_r_search(pcb_data_t *data, pcb_objtype_t types, const rnd_box_t *starting_region,
-						 rnd_r_dir_t (*region_in_search) (const rnd_box_t *region, void *cl),
-						 rnd_r_dir_t (*rectangle_in_region) (const rnd_box_t *box, void *cl),
-						 void *closure, int *num_found, rnd_bool vis_only);
+rnd_rtree_dir_t pcb_data_r_search(pcb_data_t *data, pcb_objtype_t types, const rnd_rtree_box_t *starting_region,
+						 rnd_rtree_dir_t (*region_in_search)(void *cl, void *obj, const rnd_rtree_box_t *region),
+						 rnd_rtree_dir_t (*rectangle_in_region)(void *cl, void *obj, const rnd_rtree_box_t *box),
+						 void *closure, long *num_found, rnd_bool vis_only);
 
 /* Either pcb->data or the subcircuit's data if PCB is a subc (footprint edit mode) */
 #define PCB_REAL_DATA(pcb) \
@@ -254,4 +254,6 @@ char *pcb_data_name_by_addr(int addr, char *buf);
    bytes long. Returns NULL if data is not the pcb or a buffer. */
 const char *pcb_data_to_name(pcb_board_t *pcb, pcb_data_t *data, char *buf, int buf_len);
 
+#define SUBC_AUX_NAME "subc-aux"
+
 #endif
