@@ -490,7 +490,7 @@ static void xform_setup(pcb_draw_info_t *info, rnd_xform_t *dst, const pcb_layer
 			pcb_xform_copy(dst, info->xform_caller);
 		}
 		else
-			pcb_xform_add(dst, info->xform_caller);
+			pcb_xform_add(info->xform, info->xform_caller);
 	}
 	if (info->xform_exporter != NULL) {
 		if (info->xform == NULL) {
@@ -498,7 +498,7 @@ static void xform_setup(pcb_draw_info_t *info, rnd_xform_t *dst, const pcb_layer
 			pcb_xform_copy(dst, info->xform_exporter);
 		}
 		else
-			pcb_xform_add(dst, info->xform_exporter);
+			pcb_xform_add(info->xform, info->xform_exporter);
 	}
 }
 
@@ -992,12 +992,19 @@ void pcb_draw_setup_default_xform_info(rnd_hid_t *hid, pcb_draw_info_t *info)
 }
 
 int pcb_draw_stamp = 0;
+rnd_box_t pcb_last_main_expose_region;
+
 void pcb_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *ctx, rnd_xform_t *xform_caller)
 {
 	if (!pcb_draw_inhibit) {
 		pcb_output_t save;
 		pcb_draw_info_t info;
 
+		pcb_last_main_expose_region.X1 = ctx->view.X1;
+		pcb_last_main_expose_region.Y1 = ctx->view.Y1;
+		pcb_last_main_expose_region.X2 = ctx->view.X2;
+		pcb_last_main_expose_region.Y2 = ctx->view.Y2;
+
 		expose_begin(&save, hid);
 		pcb_draw_info_setup(&info, PCB);
 		info.drawn_area = &ctx->view;
@@ -1066,7 +1073,7 @@ static const char *lab_with_intconn(const pcb_any_obj_t *term, int intconn, cons
 	dx = w / 2; \
 	dy = h / 2; \
 	if (flip_x ^ flip_y) { \
-		if (vert) \
+		if (vert && !flip_y) \
 			dx = -dx; \
 		else \
 			dy = -dy; \
