@@ -5,7 +5,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996, 2005 Thomas Nau
- *  pcb-rnd Copyright (C) 2020,2022,2023 Tibor 'Igor2' Palinkas
+ *  pcb-rnd Copyright (C) 2020,2022,2023,2024 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -166,21 +166,31 @@ static rnd_bool pcb_isc_arc_arc(const pcb_find_t *ctx, pcb_arc_t *Arc1, pcb_arc_
 	rnd_coord_t pdx, pdy;
 	rnd_coord_t box[8];
 
+	if (Bloat < 0) {
+		/* negative bloat is so severe that the whole arc disappears */
+		if ((Bloat < -Arc1->Thickness) || (Bloat < -Arc2->Thickness))
+			return rnd_false;
+	}
+
 	t = 0.5 * Arc1->Thickness + Bloat;
 	t2 = 0.5 * Arc2->Thickness;
 	t1 = t2 + Bloat;
 
-	/* too thin arc */
-	if (t < 0 || t1 < 0)
-		return rnd_false;
+	/* negative bloat can be larger arc thickness radius (thickness/2) but
+	   still smaller than the whole thickness  - the endpoint won't move
+	   by bloating, revert to using centerline (radius=0) */
+	if (t < 0)
+		t = 0;
+	if (t1 < 0)
+		t1 = 0;
 
 	/* try the end points first */
 	get_arc_ends(&box[0], Arc1);
 	get_arc_ends(&box[4], Arc2);
 	if (pcb_is_point_on_arc(box[0], box[1], t, Arc2)
 			|| pcb_is_point_on_arc(box[2], box[3], t, Arc2)
-			|| pcb_is_point_on_arc(box[4], box[5], t, Arc1)
-			|| pcb_is_point_on_arc(box[6], box[7], t, Arc1))
+			|| pcb_is_point_on_arc(box[4], box[5], t1, Arc1)
+			|| pcb_is_point_on_arc(box[6], box[7], t1, Arc1))
 		return rnd_true;
 
 	pdx = Arc2->X - Arc1->X;
@@ -523,41 +533,18 @@ static void form_slanted_rectangle(rnd_point_t p[4], pcb_line_t *l)
  *  Also note that the denominators of eqn 1 & 2 are identical.
  *
  */
-rnd_bool pcb_isc_line_line(const pcb_find_t *ctx, pcb_line_t *Line1, pcb_line_t *Line2)
+RND_INLINE rnd_bool pcb_isc_line_line_(rnd_coord_t ax1, rnd_coord_t ay1, rnd_coord_t ax2, rnd_coord_t ay2, rnd_coord_t bx1, rnd_coord_t by1, rnd_coord_t bx2, rnd_coord_t by2)
 {
 	double s, r;
 	double line1_dx, line1_dy, line2_dx, line2_dy, point1_dx, point1_dy;
-	if (PCB_FLAG_TEST(PCB_FLAG_SQUARE, Line1)) {	/* pretty reckless recursion */
-		rnd_point_t p[4];
-		form_slanted_rectangle(p, Line1);
-		return pcb_is_line_in_quadrangle(p, Line2);
-	}
-	/* here come only round Line1 because pcb_is_line_in_quadrangle()
-	   calls pcb_isc_line_line() with first argument rounded */
-	if (PCB_FLAG_TEST(PCB_FLAG_SQUARE, Line2)) {
-		rnd_point_t p[4];
-		form_slanted_rectangle(p, Line2);
-		return pcb_is_line_in_quadrangle(p, Line1);
-	}
-	/* now all lines are round */
-
-	/* Check endpoints: this provides a quick exit, catches
-	 *  cases where the "real" lines don't intersect but the
-	 *  thick lines touch, and ensures that the dx/dy business
-	 *  below does not cause a divide-by-zero. */
-	if (pcb_is_point_in_line(Line2->Point1.X, Line2->Point1.Y, MAX(Line2->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line1)
-			|| pcb_is_point_in_line(Line2->Point2.X, Line2->Point2.Y, MAX(Line2->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line1)
-			|| pcb_is_point_in_line(Line1->Point1.X, Line1->Point1.Y, MAX(Line1->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line2)
-			|| pcb_is_point_in_line(Line1->Point2.X, Line1->Point2.Y, MAX(Line1->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line2))
-		return rnd_true;
 
 	/* setup some constants */
-	line1_dx = Line1->Point2.X - Line1->Point1.X;
-	line1_dy = Line1->Point2.Y - Line1->Point1.Y;
-	line2_dx = Line2->Point2.X - Line2->Point1.X;
-	line2_dy = Line2->Point2.Y - Line2->Point1.Y;
-	point1_dx = Line1->Point1.X - Line2->Point1.X;
-	point1_dy = Line1->Point1.Y - Line2->Point1.Y;
+	line1_dx = ax2 - ax1;
+	line1_dy = ay2 - ay1;
+	line2_dx = bx2 - bx1;
+	line2_dy = by2 - by1;
+	point1_dx = ax1 - bx1;
+	point1_dy = ay1 - by1;
 
 	/* If either line is a point, we have failed already, since the
 	 *   endpoint check above will have caught an "intersection". */
@@ -591,6 +578,42 @@ rnd_bool pcb_isc_line_line(const pcb_find_t *ctx, pcb_line_t *Line1, pcb_line_t
 	return rnd_false;
 }
 
+rnd_bool pcb_geo_line_line(rnd_coord_t ax1, rnd_coord_t ay1, rnd_coord_t ax2, rnd_coord_t ay2, rnd_coord_t bx1, rnd_coord_t by1, rnd_coord_t bx2, rnd_coord_t by2)
+{
+	return pcb_isc_line_line_(ax1, ay1, ax2, ay2, bx1, by1, bx2, by2);
+}
+
+rnd_bool pcb_isc_line_line(const pcb_find_t *ctx, pcb_line_t *Line1, pcb_line_t *Line2)
+{
+	if (PCB_FLAG_TEST(PCB_FLAG_SQUARE, Line1)) {	/* pretty reckless recursion */
+		rnd_point_t p[4];
+		form_slanted_rectangle(p, Line1);
+		return pcb_is_line_in_quadrangle(p, Line2);
+	}
+	/* here come only round Line1 because pcb_is_line_in_quadrangle()
+	   calls pcb_isc_line_line() with first argument rounded */
+	if (PCB_FLAG_TEST(PCB_FLAG_SQUARE, Line2)) {
+		rnd_point_t p[4];
+		form_slanted_rectangle(p, Line2);
+		return pcb_is_line_in_quadrangle(p, Line1);
+	}
+	/* now all lines are round */
+
+	/* Check endpoints: this provides a quick exit, catches
+	 *  cases where the "real" lines don't intersect but the
+	 *  thick lines touch, and ensures that the dx/dy business
+	 *  below does not cause a divide-by-zero. */
+	if (pcb_is_point_in_line(Line2->Point1.X, Line2->Point1.Y, MAX(Line2->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line1)
+			|| pcb_is_point_in_line(Line2->Point2.X, Line2->Point2.Y, MAX(Line2->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line1)
+			|| pcb_is_point_in_line(Line1->Point1.X, Line1->Point1.Y, MAX(Line1->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line2)
+			|| pcb_is_point_in_line(Line1->Point2.X, Line1->Point2.Y, MAX(Line1->Thickness / 2 + Bloat, 0), (pcb_any_line_t *) Line2))
+		return rnd_true;
+
+	return pcb_isc_line_line_(
+		Line1->Point1.X, Line1->Point1.Y, Line1->Point2.X, Line1->Point2.Y,
+		Line2->Point1.X, Line2->Point1.Y, Line2->Point2.X, Line2->Point2.Y);
+}
+
 /*---------------------------------------------------
  *
  * Check for line intersection with an arc
@@ -868,7 +891,7 @@ rnd_bool pcb_isc_poly_poly_bloated(const pcb_find_t *ctx, rnd_pline_t *c1, rnd_p
 
 	for (c = c1; c; c = c->next) {
 		rnd_coord_t lx, ly, x, y;
-		rnd_vnode_t *v = c->head;
+		rnd_vnode_t *v = c->head, *start;
 		if (c->xmin - bloat <= c2->xmax && c->xmax + bloat >= c2->xmin &&
 				c->ymin - bloat <= c2->ymax && c->ymax + bloat >= c2->ymin) {
 
@@ -891,14 +914,15 @@ rnd_bool pcb_isc_poly_poly_bloated(const pcb_find_t *ctx, rnd_pline_t *c1, rnd_p
 			lx = v->point[0];
 			ly = v->point[1];
 
-			for (v = v->next; v != c->head; v = v->next) {
+			v = start = v->next;
+			do {
 				x = v->point[0];
 				y = v->point[1];
 				if (pcb_isc_poly_lineseg(ctx, c2, lx, ly, x, y, bloat-4)) /* -4 for compenasating for rounding errors */
 					return rnd_true;
 				lx = x;
 				ly = y;
-			}
+			} while((v = v->next) != start);
 		}
 	}
 
@@ -1146,25 +1170,82 @@ do { \
 	return rnd_false; \
 } while(0)
 
+/* Return true shape of a padstackon a layer, considering the effect of
+   drilled hole or slot; in crescent case returns tmp. After the call
+   tmp needs to be free'd using isc_pstk_shape_free */
+static pcb_pstk_shape_t *isc_pstk_shape_at(pcb_board_t *pcb, pcb_pstk_t *ps, pcb_layer_t *ly, pcb_pstk_shape_t *tmp)
+{
+	pcb_pstk_shape_t *shp = pcb_pstk_shape_at(PCB, ps, ly), htmp;
+
+	tmp->shape = PCB_PSSH_HSHADOW;
+
+	if (shp == NULL)
+		return NULL;
+
+	if (shp->hfullcover)
+		return NULL; /* shp is really drilled away */
+
+
+
+	/* deal with unplated hole/slot and crescent shapes only; in case of plated,
+	   we can take the whole hole/slot filled with copper conceptually */
+	if (shp->hcrescent) {
+		pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
+
+		if (!proto->hplated) {
+			pcb_pstk_shape_t *hole = pcb_pstk_shape_mech_at(pcb, ps, ly);
+
+			if ((hole == NULL) && (proto->hdia <= 0))
+				return shp;
+
+			if (hole == NULL) {
+				memset(&htmp, 0, sizeof(pcb_pstk_shape_t));
+				htmp.shape = PCB_PSSH_HSHADOW; /* hackish way indicate to pcb_pstk_shape_crescent_render() that it's a raw polygon */
+				htmp.data.poly.pa = rnd_poly_from_circle(ps->x, ps->y, rnd_round(proto->hdia/2.0));
+				hole = &htmp;
+			}
+
+			memset(tmp, 0, sizeof(pcb_pstk_shape_t));
+			tmp->shape = PCB_PSSH_POLY;
+			tmp->data.poly.pa = pcb_pstk_shape_crescent_render(ps, shp, hole);
+			rnd_polyarea_move(tmp->data.poly.pa, -ps->x, -ps->y); /* the caller expects non-transformed whiel all our shapes were transformed */
+			return tmp;
+		}
+	}
+
+	return shp;
+}
+
+RND_INLINE void isc_pstk_shape_free(pcb_pstk_shape_t *tmp)
+{
+	if (tmp->shape == PCB_PSSH_POLY)
+		pcb_pstk_shape_free(tmp);
+}
+
 rnd_bool_t pcb_isc_pstk_line(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_line_t *line, rnd_bool anylayer)
 {
-	pcb_pstk_shape_t *shape;
+	pcb_pstk_shape_t *shape, tmpshape;
 	pcb_pstk_proto_t *proto;
 
 	if (anylayer)
 		PCB_ISC_PSTK_ANYLAYER(ps, pcb_isc_pstk_line_shp(ctx, ps, line, &tshp->shape[n]));
 
-	shape = pcb_pstk_shape_at(PCB, ps, line->parent.layer);
-	if (pcb_isc_pstk_line_shp(ctx, ps, line, shape))
+	shape = isc_pstk_shape_at(PCB, ps, line->parent.layer, &tmpshape);
+	if (pcb_isc_pstk_line_shp(ctx, ps, line, shape)) {
+		isc_pstk_shape_free(&tmpshape);
 		return rnd_true;
+	}
 
 	proto = pcb_pstk_get_proto(ps);
 	if (proto->hplated) {
 		shape = pcb_pstk_shape_mech_at(PCB, ps, line->parent.layer);
-		if (pcb_isc_pstk_line_shp(ctx, ps, line, shape))
+		if (pcb_isc_pstk_line_shp(ctx, ps, line, shape)) {
+			isc_pstk_shape_free(&tmpshape);
 			return rnd_true;
+		}
 	}
 
+	isc_pstk_shape_free(&tmpshape);
 	return rnd_false;
 }
 
@@ -1221,23 +1302,28 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_arc_shp(const pcb_find_t *ctx, pcb_pstk_t *ps
 
 RND_INLINE rnd_bool_t pcb_isc_pstk_arc(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_arc_t *arc, rnd_bool anylayer)
 {
-	pcb_pstk_shape_t *shape;
+	pcb_pstk_shape_t *shape, tmpshape;
 	pcb_pstk_proto_t *proto;
 
 	if (anylayer)
 		PCB_ISC_PSTK_ANYLAYER(ps, pcb_isc_pstk_arc_shp(ctx, ps, arc, &tshp->shape[n]));
 
-	shape = pcb_pstk_shape_at(PCB, ps, arc->parent.layer);
-	if (pcb_isc_pstk_arc_shp(ctx, ps, arc, shape))
+	shape = isc_pstk_shape_at(PCB, ps, arc->parent.layer, &tmpshape);
+	if (pcb_isc_pstk_arc_shp(ctx, ps, arc, shape)) {
+		isc_pstk_shape_free(&tmpshape);
 		return rnd_true;
+	}
 
 	proto = pcb_pstk_get_proto(ps);
 	if (proto->hplated) {
 		shape = pcb_pstk_shape_mech_at(PCB, ps, arc->parent.layer);
-		if (pcb_isc_pstk_arc_shp(ctx, ps, arc, shape))
+		if (pcb_isc_pstk_arc_shp(ctx, ps, arc, shape)) {
+			isc_pstk_shape_free(&tmpshape);
 			return rnd_true;
+		}
 	}
 
+	isc_pstk_shape_free(&tmpshape);
 	return rnd_false;
 }
 
@@ -1368,7 +1454,7 @@ rnd_polyarea_t *pcb_pstk_shape2polyarea(pcb_pstk_t *ps, pcb_pstk_shape_t *shape)
 
 RND_INLINE rnd_bool_t pcb_isc_pstk_poly(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_poly_t *poly, rnd_bool anylayer)
 {
-	pcb_pstk_shape_t *shape;
+	pcb_pstk_shape_t *shape, tmpshape;
 	pcb_pstk_proto_t *proto;
 	rnd_coord_t clr;
 
@@ -1388,17 +1474,22 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_poly(const pcb_find_t *ctx, pcb_pstk_t *ps, p
 		}
 	}
 
-	shape = pcb_pstk_shape_at(PCB, ps, poly->parent.layer);
-	if (pcb_isc_pstk_poly_shp(ctx, ps, poly, shape))
+	shape = isc_pstk_shape_at(PCB, ps, poly->parent.layer, &tmpshape);
+	if (pcb_isc_pstk_poly_shp(ctx, ps, poly, shape)) {
+		isc_pstk_shape_free(&tmpshape);
 		return rnd_true;
+	}
 
 	proto = pcb_pstk_get_proto(ps);
 	if (proto->hplated) {
 		shape = pcb_pstk_shape_mech_at(PCB, ps, poly->parent.layer);
-		if (pcb_isc_pstk_poly_shp(ctx, ps, poly, shape))
+		if (pcb_isc_pstk_poly_shp(ctx, ps, poly, shape)) {
+			isc_pstk_shape_free(&tmpshape);
 			return rnd_true;
+		}
 	}
 
+	isc_pstk_shape_free(&tmpshape);
 	return rnd_false;
 }
 
@@ -1502,6 +1593,7 @@ rnd_bool_t pcb_pstk_shape_intersect(pcb_pstk_t *ps1, pcb_pstk_shape_t *shape1, p
 RND_INLINE rnd_bool_t pcb_isc_pstk_pstk(const pcb_find_t *ctx, pcb_pstk_t *ps1, pcb_pstk_t *ps2, rnd_bool anylayer)
 {
 	pcb_layer_t *ly;
+	pcb_pstk_shape_t tmpshape1, tmpshape2;
 	pcb_pstk_proto_t *proto1, *proto2;
 	int n;
 
@@ -1528,21 +1620,25 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_pstk(const pcb_find_t *ctx, pcb_pstk_t *ps1,
 		if (!ctx->allow_noncopper_pstk && !(lyt & PCB_LYT_COPPER)) /* consider only copper for connections */
 			continue;
 
-		shape1 = pcb_pstk_shape_at(PCB, ps1, ly);
-		shape2 = pcb_pstk_shape_at(PCB, ps2, ly);
+#define CLEANUP isc_pstk_shape_free(&tmpshape1); isc_pstk_shape_free(&tmpshape2)
+		shape1 = isc_pstk_shape_at(PCB, ps1, ly, &tmpshape1);
+		shape2 = isc_pstk_shape_at(PCB, ps2, ly, &tmpshape2);
 
-		if ((shape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, shape1, ps2, shape2)) return rnd_true;
+		if ((shape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, shape1, ps2, shape2)) { CLEANUP; return rnd_true; }
 
 		if (proto1->hplated)
 			slshape1 = pcb_pstk_shape_mech_or_hole_at(PCB, ps1, ly, &sltmp1);
 		if (proto2->hplated)
 			slshape2 = pcb_pstk_shape_mech_or_hole_at(PCB, ps2, ly, &sltmp2);
 
-		if ((slshape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, slshape1, ps2, shape2)) return rnd_true;
-		if ((slshape2 != NULL) && (shape1 != NULL) && pcb_pstk_shape_intersect_(ctx, ps2, slshape2, ps1, shape1)) return rnd_true;
-		if ((slshape1 != NULL) && (slshape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, slshape1, ps2, slshape2)) return rnd_true;
+		if ((slshape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, slshape1, ps2, shape2)) { CLEANUP; return rnd_true; }
+		if ((slshape2 != NULL) && (shape1 != NULL) && pcb_pstk_shape_intersect_(ctx, ps2, slshape2, ps1, shape1)) { CLEANUP; return rnd_true; }
+		if ((slshape1 != NULL) && (slshape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, slshape1, ps2, slshape2)) { CLEANUP; return rnd_true; }
 	}
+
+	CLEANUP;
 	return rnd_false;
+#undef CLEANUP
 }
 
 
@@ -1552,6 +1648,9 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_rat(const pcb_find_t *ctx, pcb_pstk_t *ps, pc
 
 	PCB_ISC_RAT_BY_IDPATH(ctx, rat, (pcb_any_obj_t *)ps);
 
+	/* this is the only case where we use pcb_pstk_shape_at() directly because
+	   the rat code wouldn't filter out non-existing copper either */
+
 	if ((rat->Point1.X == ps->x) && (rat->Point1.Y == ps->y)) {
 		pcb_layer_t *layer = pcb_get_layer(pcb->Data, pcb->LayerGroups.grp[rat->group1].lid[0]);
 		if ((layer != NULL) && (pcb_pstk_shape_at(pcb, ps, layer) != NULL))
