@@ -789,7 +789,7 @@ int pcb_layer_gui_set_layer(rnd_layergrp_id_t gid, const pcb_layergrp_t *grp, in
 		*xform = NULL;
 
 	if (rnd_render->set_layer_group != NULL)
-		return rnd_render->set_layer_group(rnd_gui, gid, grp->purpose, grp->purpi, grp->lid[0], grp->ltype, is_empty, xform);
+		return rnd_render->set_layer_group(rnd_gui, &PCB->hidlib, gid, grp->purpose, grp->purpi, grp->lid[0], grp->ltype, is_empty, xform);
 
 	/* if the GUI doesn't have a set_layer, assume it wants to draw all layers */
 	return 1;
