@@ -503,6 +503,7 @@ void pcb_gfx_rotate90(pcb_gfx_t *gfx, rnd_coord_t X, rnd_coord_t Y, unsigned Num
 {
 	gfx->rot = rnd_normalize_angle(gfx->rot + Number * 90);
 	gfx->pxm_xformed = pcb_pixmap_alloc_insert_transformed(&pcb_pixmaps, gfx->pxm_neutral, gfx->rot, gfx->sx, gfx->sy, gfx->xmirror, gfx->ymirror);
+	RND_COORD_ROTATE90(gfx->cx, gfx->cy, X, Y, Number);
 	pcb_gfx_update(gfx);
 	pcb_gfx_bbox(gfx);
 }
@@ -514,6 +515,7 @@ void pcb_gfx_rotate(pcb_layer_t *layer, pcb_gfx_t *gfx, rnd_coord_t X, rnd_coord
 
 	gfx->rot = rnd_normalize_angle(gfx->rot + angle);
 	gfx->pxm_xformed = pcb_pixmap_alloc_insert_transformed(&pcb_pixmaps, gfx->pxm_neutral, gfx->rot, gfx->sx, gfx->sy, gfx->xmirror, gfx->ymirror);
+	rnd_rotate(&gfx->cx, &gfx->cy, X, Y, cosa, sina);
 	pcb_gfx_update(gfx);
 	pcb_gfx_bbox(gfx);
 
@@ -528,15 +530,13 @@ void pcb_gfx_mirror(pcb_gfx_t *gfx, rnd_coord_t y_offs, rnd_bool undoable)
 	if (undoable) g = pcb_undo_alloc(pcb_data_get_top(gfx->parent.layer->parent.data), &undo_gfx_geo, sizeof(undo_gfx_geo_t));
 
 	g->gfx = gfx;
-	g->cx = gfx->cx;
-	g->cy = gfx->cy;
+	g->cx = PCB_SWAP_X(gfx->cx);
+	g->cy = PCB_SWAP_Y(gfx->cy) + y_offs;
 	g->sx = gfx->sx;
 	g->sy = gfx->sy;
 	g->rot = gfx->rot;
 	g->xmirror = gfx->xmirror;
-	g->ymirror = gfx->ymirror;
-
-TODO("probably need to swap y mirror");
+	g->ymirror = !gfx->ymirror;
 
 	undo_gfx_geo_swap(g);
 	if (undoable) pcb_undo_inc_serial();
@@ -599,8 +599,8 @@ void pcb_gfx_scale(pcb_gfx_t *gfx, double sx, double sy, double sth)
 	if (onbrd)
 		pcb_gfx_pre(gfx);
 
-	if (sx != 1.0) gfx->sx = rnd_round((double)gfx->sx * sx);
-	if (sy != 1.0) gfx->sy = rnd_round((double)gfx->sy * sy);
+	if (sx != 1.0) { gfx->sx = rnd_round((double)gfx->sx * sx); gfx->cx *= sx; }
+	if (sy != 1.0) { gfx->sy = rnd_round((double)gfx->sy * sy); gfx->cy *= sy; }
 
 	pcb_gfx_bbox(gfx);
 	if (onbrd)
@@ -699,6 +699,8 @@ void pcb_gfx_resize_move_corner(pcb_gfx_t *gfx, int corn_idx, rnd_coord_t dx, rn
 	g->cy = gfx->cy + rnd_round((double)dy / 2.0);;
 	g->sx = nsx;
 	g->sy = nsy;
+	g->xmirror = gfx->xmirror;
+	g->ymirror = gfx->ymirror;
 	g->rot = gfx->rot;
 
 	undo_gfx_geo_swap(g);
