@@ -83,7 +83,7 @@ pcb_rat_t *pcb_rat_alloc(pcb_data_t *data)
 void pcb_rat_free(pcb_rat_t *rat)
 {
 	if ((rat->parent.data != NULL) && (rat->parent.data->rat_tree != NULL))
-		rnd_r_delete_entry(rat->parent.data->rat_tree, (rnd_box_t *)rat);
+		rnd_rtree_delete(rat->parent.data->rat_tree, rat, (rnd_rtree_box_t *)rat);
 	pcb_rat_unreg(rat);
 	free(rat->anchor[0]);
 	free(rat->anchor[1]);
@@ -117,8 +117,8 @@ pcb_rat_t *pcb_rat_new(pcb_data_t *Data, long int id, rnd_coord_t X1, rnd_coord_
 	Line->group2 = group2;
 	pcb_line_bbox((pcb_line_t *) Line);
 	if (!Data->rat_tree)
-		Data->rat_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Data->rat_tree, &Line->BoundingBox);
+		rnd_rtree_init(Data->rat_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Data->rat_tree, Line, (rnd_rtree_box_t *)Line);
 
 	if (anchor1 != NULL)
 		Line->anchor[0] = pcb_obj2idpath(anchor1);
@@ -341,7 +341,7 @@ void *pcb_ratop_add_to_buffer(pcb_opctx_t *ctx, pcb_rat_t *Rat)
 /* moves a rat-line between board and buffer */
 void *pcb_ratop_move_buffer(pcb_opctx_t *ctx, pcb_rat_t * rat)
 {
-	rnd_r_delete_entry(ctx->buffer.src->rat_tree, (rnd_box_t *) rat);
+	rnd_rtree_delete(ctx->buffer.src->rat_tree, rat, (rnd_rtree_box_t *)rat);
 
 	pcb_rat_unreg(rat);
 	pcb_rat_reg(ctx->buffer.dst, rat);
@@ -349,8 +349,8 @@ void *pcb_ratop_move_buffer(pcb_opctx_t *ctx, pcb_rat_t * rat)
 	PCB_FLAG_CLEAR(PCB_FLAG_FOUND, rat);
 
 	if (!ctx->buffer.dst->rat_tree)
-		ctx->buffer.dst->rat_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(ctx->buffer.dst->rat_tree, (rnd_box_t *) rat);
+		rnd_rtree_init(ctx->buffer.dst->rat_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(ctx->buffer.dst->rat_tree, rat, (rnd_rtree_box_t *)rat);
 
 	return rat;
 }
@@ -399,7 +399,7 @@ void *pcb_ratop_move_to_layer(pcb_opctx_t *ctx, pcb_rat_t * Rat)
 void *pcb_ratop_destroy(pcb_opctx_t *ctx, pcb_rat_t *Rat)
 {
 	if (ctx->remove.destroy_target->rat_tree)
-		rnd_r_delete_entry(ctx->remove.destroy_target->rat_tree, &Rat->BoundingBox);
+		rnd_rtree_delete(ctx->remove.destroy_target->rat_tree, Rat, (rnd_rtree_box_t *)Rat);
 
 	pcb_rat_free(Rat);
 	return NULL;
@@ -416,9 +416,9 @@ void *pcb_ratop_remove(pcb_opctx_t *ctx, pcb_rat_t *Rat)
 }
 
 /*** draw ***/
-rnd_r_dir_t pcb_rat_draw_callback(const rnd_box_t * b, void *cl)
+rnd_rtree_dir_t pcb_rat_draw_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_rat_t *rat = (pcb_rat_t *) b;
+	pcb_rat_t *rat = (pcb_rat_t *)obj;
 	pcb_draw_info_t *info = cl;
 
 	if (PCB_FLAG_TEST(PCB_FLAG_SELECTED | PCB_FLAG_FOUND, rat)) {
@@ -433,7 +433,9 @@ rnd_r_dir_t pcb_rat_draw_callback(const rnd_box_t * b, void *cl)
 	else
 		rnd_render->set_color(pcb_draw_out.fgGC, &conf_core.appearance.color.rat);
 
-	if (conf_core.appearance.rat_thickness < 20)
+	if (conf_core.appearance.rat_thickness < 0)
+		rat->Thickness = conf_core.appearance.rat_thickness;
+	else if (conf_core.appearance.rat_thickness < 20)
 		rat->Thickness = rnd_pixel_slop * conf_core.appearance.rat_thickness;
 	/* PCB_FLAG_VIA is set if this rat goes to a containing poly: draw a donut */
 	if (PCB_FLAG_TEST(PCB_FLAG_VIA, rat)) {
@@ -447,7 +449,7 @@ rnd_r_dir_t pcb_rat_draw_callback(const rnd_box_t * b, void *cl)
 	}
 	else
 		pcb_line_draw_(info, (pcb_line_t *) rat, 0);
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
 void pcb_rat_invalidate_erase(pcb_rat_t *Rat)
@@ -465,7 +467,6 @@ void pcb_rat_invalidate_erase(pcb_rat_t *Rat)
 	}
 	else
 		pcb_line_invalidate_erase((pcb_line_t *) Rat);
-	pcb_flag_erase(&Rat->Flags);
 }
 
 void pcb_rat_invalidate_draw(pcb_rat_t *Rat)
