@@ -32,7 +32,7 @@
 #include "layer.h"
 
 /* Returns the subc a global (on-data) object is part of (or NULL if not part of any subc) */
-PCB_INLINE pcb_subc_t *pcb_gobj_parent_subc(pcb_parenttype_t pt, const pcb_parent_t *p)
+RND_INLINE pcb_subc_t *pcb_gobj_parent_subc(pcb_parenttype_t pt, const pcb_parent_t *p)
 {
 	if (pt != PCB_PARENT_DATA)
 		return NULL;
@@ -46,7 +46,7 @@ PCB_INLINE pcb_subc_t *pcb_gobj_parent_subc(pcb_parenttype_t pt, const pcb_paren
 }
 
 /* Returns the subc a layer object is part of (or NULL if not part of any subc) */
-PCB_INLINE pcb_subc_t *pcb_lobj_parent_subc(pcb_parenttype_t pt, const pcb_parent_t *p)
+RND_INLINE pcb_subc_t *pcb_lobj_parent_subc(pcb_parenttype_t pt, const pcb_parent_t *p)
 {
 	if (pt != PCB_PARENT_LAYER)
 		return NULL;
@@ -63,7 +63,7 @@ PCB_INLINE pcb_subc_t *pcb_lobj_parent_subc(pcb_parenttype_t pt, const pcb_paren
 }
 
 /* Returns the subc an object is part of (or NULL if not part of any subc) */
-PCB_INLINE pcb_subc_t *pcb_obj_parent_subc(const pcb_any_obj_t *obj)
+RND_INLINE pcb_subc_t *pcb_obj_parent_subc(const pcb_any_obj_t *obj)
 {
 	switch(obj->type) {
 		case PCB_OBJ_PSTK:
@@ -74,6 +74,7 @@ PCB_INLINE pcb_subc_t *pcb_obj_parent_subc(const pcb_any_obj_t *obj)
 		case PCB_OBJ_POLY:
 		case PCB_OBJ_TEXT:
 		case PCB_OBJ_ARC:
+		case PCB_OBJ_GFX:
 			return pcb_lobj_parent_subc(obj->parent_type, &obj->parent);
 
 		default:
@@ -83,21 +84,21 @@ PCB_INLINE pcb_subc_t *pcb_obj_parent_subc(const pcb_any_obj_t *obj)
 	return 0;
 }
 
-PCB_INLINE pcb_bool_t pcb_obj_is_under(pcb_any_obj_t *obj, pcb_data_t *data)
+RND_INLINE rnd_bool_t pcb_obj_is_under(pcb_any_obj_t *obj, pcb_data_t *data)
 {
 	for(;;) {
 		switch(obj->parent_type) {
-			case PCB_PARENT_INVALID: return pcb_false;
-			case PCB_PARENT_BOARD:   return pcb_false;
-			case PCB_PARENT_UI:      return pcb_false; /* shouldn't happen */
-			case PCB_PARENT_LAYER:   if (obj->parent.layer->parent.data == data) return pcb_true; break;
-			case PCB_PARENT_SUBC:    if (obj->parent.subc->data == data) return pcb_true; break;
-			case PCB_PARENT_DATA:    if (obj->parent.data == data) return pcb_true; break;
-			case PCB_PARENT_NET:     if (obj->parent.data == data) return pcb_true; break;
+			case PCB_PARENT_INVALID: return rnd_false;
+			case PCB_PARENT_BOARD:   return rnd_false;
+			case PCB_PARENT_UI:      return rnd_false; /* shouldn't happen */
+			case PCB_PARENT_LAYER:   if (obj->parent.layer->parent.data == data) return rnd_true; break;
+			case PCB_PARENT_SUBC:    if (obj->parent.subc->data == data) return rnd_true; break;
+			case PCB_PARENT_DATA:    if (obj->parent.data == data) return rnd_true; break;
+			case PCB_PARENT_NET:     if (obj->parent.data == data) return rnd_true; break;
 		}
 		obj = (pcb_any_obj_t *)pcb_obj_parent_subc(obj);
 		if (obj == NULL)
-			return pcb_false;
+			return rnd_false;
 	}
 }
 
