@@ -55,6 +55,11 @@
 #include <librnd/poly/polygon1_gen.h>
 #include "event.h"
 
+#if PCB_WANT_POLYBOOL2
+extern rnd_cardinal_t rnd_polyarea_split_selfisc(rnd_polyarea_t **pa);
+#endif
+
+
 #define UNSUBTRACT_BLOAT 10
 #define SUBTRACT_PIN_VIA_BATCH_SIZE 100
 #define SUBTRACT_PADSTACK_BATCH_SIZE 50
@@ -189,6 +194,7 @@ static rnd_polyarea_t *biggest(rnd_polyarea_t * p)
 	n = p;
 	do {
 #if 0
+		TODO("#isle: remove this code: was disabled in pcb 2007 and latest 4.3 too");
 		if (n->contours->area < conf_core.design.poly_isle_area) {
 			n->b->f = n->f;
 			n->f->b = n->b;
@@ -223,6 +229,17 @@ static rnd_polyarea_t *biggest(rnd_polyarea_t * p)
 	return p;
 }
 
+static long num_islands(rnd_polyarea_t *start)
+{
+	rnd_polyarea_t *pa;
+	long cnt = 1;
+
+	for(pa = start->f; pa != start; pa = pa->f)
+		cnt++;
+
+	return cnt;
+}
+
 rnd_polyarea_t *pcb_poly_to_polyarea(pcb_poly_t *p, rnd_bool *need_full)
 {
 	rnd_pline_t *contour = NULL;
@@ -264,12 +281,21 @@ rnd_polyarea_t *pcb_poly_to_polyarea(pcb_poly_t *p, rnd_bool *need_full)
 			rnd_polyarea_contour_include(np, contour);
 			contour = NULL;
 
-TODO("multiple plines within the returned polyarea np does not really work\n");
-#if 0
+#if PCB_WANT_POLYBOOL2
 			if (!rnd_poly_valid(np)) {
-				rnd_cardinal_t cnt = rnd_polyarea_split_selfint(np);
-				rnd_message(RND_MSG_ERROR, "Had to split up self-intersecting polygon into %ld parts\n", (long)cnt);
-				if (cnt > 1)
+				int np1_is_np = (np1 == np);
+				long diff, cnt0, cnt1;
+
+				cnt0 = num_islands(np);
+				rnd_polyarea_split_selfisc(&np); /* may result in multiple islands, even the value of np may change */
+				cnt1 = num_islands(np);
+				if (np1_is_np)
+					np1 = np;
+
+				diff = cnt1-cnt0+1;
+				rnd_message(RND_MSG_ERROR, "Had to split up self-intersecting polygon into %ld parts\nThis is an error in your data, please fix your polygon!\nObject ID: #%ld, first as-drawn point is %.3$mm;%.3$mm\n",
+					diff, p->ID, p->Points[0].X, p->Points[0].Y);
+				if (diff > 1)
 					*need_full = rnd_true;
 				assert(rnd_poly_valid(np));
 			}
@@ -1092,8 +1118,8 @@ int pcb_poly_init_clip_prog(pcb_data_t *Data, pcb_layer_t *layer, pcb_poly_t *p,
 		rnd_polyarea_free(&p->Clipped);
 	p->Clipped = pcb_poly_to_polyarea(p, &need_full);
 	if (need_full && !PCB_FLAG_TEST(PCB_FLAG_FULLPOLY, p)) {
-		rnd_message(RND_MSG_WARNING, "Polygon #%ld was self intersecting; it had to be split up and\nthe full poly flag set.\n", (long)p->ID);
-		PCB_FLAG_SET(PCB_FLAG_FULLPOLY, p);
+		/* can't set FULLPOLY because thius runs on load and changing object flags would break compatibility */
+		rnd_message(RND_MSG_WARNING, "Polygon #%ld was self intersecting; it had to be split up.\nSome islands may disappear because the FULLPOLY flag is not set.\n", (long)p->ID);
 	}
 	rnd_poly_contours_free(&p->NoHoles);
 
@@ -1631,6 +1657,10 @@ rnd_bool pcb_poly_isects_poly(rnd_polyarea_t * a, pcb_poly_t *p, rnd_bool fr)
 {
 	rnd_polyarea_t *x;
 	rnd_bool ans;
+
+	if (p->Clipped == NULL)
+		return 0;
+
 	ans = rnd_polyarea_touching(a, p->Clipped);
 	/* argument may be register, so we must copy it */
 	x = a;
@@ -1644,8 +1674,13 @@ rnd_bool pcb_poly_is_point_in_p(rnd_coord_t X, rnd_coord_t Y, rnd_coord_t r, pcb
 {
 	rnd_polyarea_t *c;
 	rnd_vector_t v;
+
+	if (p->Clipped == NULL)
+		return 0;
+
 	v[0] = X;
 	v[1] = Y;
+
 	if (rnd_polyarea_contour_inside(p->Clipped, v))
 		return rnd_true;
 
