@@ -513,7 +513,7 @@ static rnd_bool SearchPointByLocation(unsigned long Type, unsigned long objst, u
 	ctx.Type = Type;
 	ctx.Polygon = Polygon;
 	ctx.Point = Point;
-	ctx.found = rnd_false;;
+	ctx.found = rnd_false;
 	ctx.least = SearchRadius + PCB_MAX_POLYGON_POINT_DISTANCE;
 	ctx.least = ctx.least * ctx.least;
 	rnd_rtree_search_any(SearchLayer->polygon_tree, (rnd_rtree_box_t *)&SearchBox, NULL, polypoint_callback, &ctx, NULL);
@@ -577,7 +577,7 @@ static rnd_bool SearchGfxPointByLocation(unsigned long Type, unsigned long objst
 	ctx.Type = Type;
 	ctx.gfx = gfx;
 	ctx.Point = Point;
-	ctx.found = rnd_false;;
+	ctx.found = rnd_false;
 	ctx.least = SearchRadius + PCB_MAX_POLYGON_POINT_DISTANCE;
 	ctx.least = ctx.least * ctx.least;
 	rnd_rtree_search_any(SearchLayer->gfx_tree, (rnd_rtree_box_t *)&SearchBox, NULL, gfxpoint_callback, &ctx, NULL);
@@ -719,12 +719,12 @@ rnd_bool pcb_is_point_on_line_end(rnd_coord_t X, rnd_coord_t Y, pcb_rat_t *Line)
  *   distance^2 = (X-QX)^2 + (Y-QY)^2
  */
 
-double pcb_point_line_dist2(rnd_coord_t X, rnd_coord_t Y, pcb_line_t *Line)
+RND_INLINE double pcb_point_line_dist2_abstract(rnd_coord_t px, rnd_coord_t py, rnd_coord_t lx1, rnd_coord_t ly1, rnd_coord_t lx2, rnd_coord_t ly2, double *offs_out, double *prjx_out, double *prjy_out)
 {
-	const double abx = Line->Point2.X - Line->Point1.X;
-	const double aby = Line->Point2.Y - Line->Point1.Y;
-	const double apx = X - Line->Point1.X;
-	const double apy = Y - Line->Point1.Y;
+	const double abx = lx2 - lx1;
+	const double aby = ly2 - ly1;
+	const double apx = px - lx1;
+	const double apy = py - ly1;
 	double qx,qy,dx,dy;
 
 	/* Calculate t, the normalised position along the line of the closest point 
@@ -733,21 +733,36 @@ double pcb_point_line_dist2(rnd_coord_t X, rnd_coord_t Y, pcb_line_t *Line)
 	 */
 	double t = ( (apx * abx) + (apy * aby) ) / ( (abx * abx) + (aby * aby) );
 
+	if (offs_out != NULL) *offs_out = t;
+	if (prjx_out != NULL) *prjx_out = lx1 + (t * abx);
+	if (prjy_out != NULL) *prjy_out = ly1 + (t * aby);
+
 	/* Clamp 't' to the line bounds */
 	if(t < 0.0)		t = 0.0;
 	if(t > 1.0)		t = 1.0;
 
 	/* Calculate the point Q on the line that is closest to (X,Y) */
-	qx = Line->Point1.X + (t * abx);
-	qy = Line->Point1.Y + (t * aby);
+	qx = lx1 + (t * abx);
+	qy = ly1 + (t * aby);
 
 	/* Return the distance from Q to (X,Y), squared */
-	dx = X - qx;
-	dy = Y - qy;
+	dx = px - qx;
+	dy = py - qy;
 
 	return (dx * dx) + (dy * dy);
 }
 
+double pcb_point_line_dist2(rnd_coord_t X, rnd_coord_t Y, pcb_line_t *Line)
+{
+	return pcb_point_line_dist2_abstract(X, Y, Line->Point1.X, Line->Point1.Y, Line->Point2.X, Line->Point2.Y, NULL, NULL, NULL);
+}
+
+double pcb_geo_point_line_dist2(rnd_coord_t px, rnd_coord_t py, rnd_coord_t lx1, rnd_coord_t ly1, rnd_coord_t lx2, rnd_coord_t ly2, double *offs_out, double *prjx_out, double *prjy_out)
+{
+	return pcb_point_line_dist2_abstract(px, py, lx1, ly1, lx2, ly2, offs_out, prjx_out, prjy_out);
+}
+
+
 rnd_bool pcb_is_point_on_line(rnd_coord_t X, rnd_coord_t Y, rnd_coord_t Radius, pcb_line_t *Line)
 {
 	double max = Radius + Line->Thickness / 2;
@@ -834,7 +849,7 @@ rnd_bool pcb_is_line_in_rectangle(rnd_coord_t X1, rnd_coord_t Y1, rnd_coord_t X2
 }
 
 /*checks if a point (of null radius) is in a slanted rectangle */
-static int IsPointInQuadrangle(rnd_point_t p[4], rnd_point_t *l)
+RND_INLINE int IsPointInQuadrangle(rnd_point_t p[4], rnd_point_t *l)
 {
 	rnd_coord_t dx, dy, x, y;
 	double prod0, prod1;
@@ -860,6 +875,12 @@ static int IsPointInQuadrangle(rnd_point_t p[4], rnd_point_t *l)
 	return rnd_false;
 }
 
+int pcb_geo_pt_in_quadrangle(rnd_point_t p[4], rnd_point_t *l)
+{
+	return IsPointInQuadrangle(p, l);
+}
+
+
 /* ---------------------------------------------------------------------------
  * checks if a line crosses a quadrangle or is within the quadrangle: almost
  * copied from pcb_is_line_in_rectangle()
@@ -1297,15 +1318,15 @@ static int pcb_search_obj_by_loc_layer(unsigned long Type, void **Result1, void
 	if (SearchLayer->meta.real.vis) {
 		/* GFX searched first because if it is rendered above, it is visible over
 		   the others */
-		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 && Type & PCB_OBJ_GFX &&
-				SearchGfxByLocation(objst, req_flag, (pcb_layer_t **)Result1, (pcb_gfx_t **)Result2, (pcb_gfx_t **)Result3, +1))
-			return PCB_OBJ_GFX;
-
 		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 &&
 				Type & PCB_OBJ_GFX_POINT &&
 				SearchGfxPointByLocation(Type, objst, req_flag, (pcb_layer_t **) Result1, (pcb_gfx_t **) Result2, (rnd_point_t **) Result3))
 			return PCB_OBJ_GFX_POINT;
 
+		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 && Type & PCB_OBJ_GFX &&
+				SearchGfxByLocation(objst, req_flag, (pcb_layer_t **)Result1, (pcb_gfx_t **)Result2, (pcb_gfx_t **)Result3, +1))
+			return PCB_OBJ_GFX;
+
 		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 &&
 				Type & PCB_OBJ_POLY_POINT &&
 				SearchPointByLocation(Type, objst, req_flag, (pcb_layer_t **) Result1, (pcb_poly_t **) Result2, (rnd_point_t **) Result3))
