@@ -40,9 +40,9 @@
 #include <librnd/core/error.h>
 #include <librnd/core/event.h>
 #include "integrity.h"
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_attrib.h>
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_attrib.h>
+#include <librnd/hid/hid_dad.h>
 #include "search.h"
 #include "plug_footprint.h"
 #include "plug_io.h"
@@ -285,7 +285,7 @@ static fgw_error_t pcb_act_dumpflags(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
-static void ev_ui_post(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void ev_ui_post(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 
 	if (conf_diag.plugins.diag.auto_integrity) {
