@@ -30,7 +30,7 @@
 #include "change.h"
 #include "conf_core.h"
 #include "event.h"
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 #include "stub_draw.h"
 #include "idpath.h"
 #include "search.h"
@@ -72,7 +72,7 @@ static void fontsel_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 		memset(ctx, 0, sizeof(fontsel_ctx_t));
 }
 
-void fontsel_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+void fontsel_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 	fontsel_ctx_t *ctx = prv->user_ctx;
 
@@ -265,7 +265,7 @@ fgw_error_t pcb_act_Fontsel(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
-static void fontsel_mchanged_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void fontsel_mchanged_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	fontsel_ctx_t *c;
 
@@ -276,7 +276,7 @@ static void fontsel_mchanged_ev(rnd_hidlib_t *hidlib, void *user_data, int argc,
 		fontsel_preview_update(c);
 }
 
-static void fontsel_bchanged_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void fontsel_bchanged_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	fontsel_ctx_t *c, *next;
 	rnd_dad_retovr_t retovr;
@@ -310,7 +310,7 @@ static void fontsel_timer_cb(rnd_hidval_t user_data)
 	fontsel_timer = rnd_gui->add_timer(rnd_gui, fontsel_timer_cb, 500, fontsel_timer);
 }
 
-static void fontsel_gui_init_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void fontsel_gui_init_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	fontsel_timer_cb(fontsel_timer);
 	fontsel_timer_active = 1;
@@ -325,8 +325,8 @@ void pcb_dlg_fontsel_uninit(void)
 
 void pcb_dlg_fontsel_init(void)
 {
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, fontsel_bchanged_ev, NULL, fontsel_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_META_CHANGED, fontsel_mchanged_ev, NULL, fontsel_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, fontsel_bchanged_ev, NULL, fontsel_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_META_CHANGED, fontsel_mchanged_ev, NULL, fontsel_cookie);
 	rnd_event_bind(PCB_EVENT_FONT_CHANGED, fontsel_mchanged_ev, NULL, fontsel_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, fontsel_gui_init_ev, NULL, fontsel_cookie);
 }
