@@ -4,7 +4,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 2006 DJ Delorie
- *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2022,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -58,6 +58,7 @@
 #include "event.h"
 #include "polygon.h"
 #include "obj_poly_draw.h"
+#include "preview.h"
 
 /* FIXME - we currently hardcode the grid and PCB size.  What we
    should do in the future is scan the font for its extents, and size
@@ -81,12 +82,20 @@ static pcb_layer_t *make_layer(pcb_board_t *pcb, rnd_layergrp_id_t grp, const ch
 	return &pcb->Data->Layer[lid];
 }
 
+/* Remember the original font we are editing; some metadata are not represented
+   graphically and can not be converted back from graphics - those are loaded
+   from here when converting the graphics back to a font for saving */
+rnd_font_t *fontedit_src;
+
 static void font2editor_new(pcb_board_t *pcb, rnd_font_t *font, pcb_layer_t *lfont, pcb_layer_t *lorig, pcb_layer_t *lwidth, pcb_layer_t *lsilk)
 {
 	int s;
 	long n;
 	rnd_glyph_t *g;
 
+	/* remember the font for fields not represente graphically */
+	fontedit_src = font;
+
 	for(s = 0, g = font->glyph; s <= RND_FONT_MAX_GLYPHS; s++,g++) {
 		char txt[32];
 		rnd_glyph_atom_t *a;
@@ -167,12 +176,17 @@ static void font2editor_new(pcb_board_t *pcb, rnd_font_t *font, pcb_layer_t *lfo
 			}
 		}
 
-		w = maxx + g->xdelta + ox;
+		if ((s == 'i') || (s == 'q'))
+			rnd_trace("delta1: %c w=%ld + %ld + %ld=%ld | adv: %d %ld + %ld = %ld\n", s, g->width, g->xdelta, ox, g->width + g->xdelta + ox, g->advance_valid, g->advance, ox, g->advance + ox);
+		if (g->advance_valid)
+			w = g->advance + ox;
+		else
+			w = g->width + g->xdelta + ox;
 		pcb_line_new_merge(lwidth, w, miny + oy, w, maxy + oy, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
 	}
 }
 
-static void editor2font(pcb_board_t *pcb, rnd_font_t *font)
+void editor2font(pcb_board_t *pcb, rnd_font_t *font, const rnd_font_t *orig_font)
 {
 	rnd_glyph_t *g;
 	int i;
@@ -183,7 +197,6 @@ static void editor2font(pcb_board_t *pcb, rnd_font_t *font)
 	pcb_layer_t *lfont, *lwidth;
 	rnd_glyph_poly_t *gp;
 
-
 	lfont = pcb->Data->Layer + 0;
 	lwidth = pcb->Data->Layer + 2;
 
@@ -271,6 +284,13 @@ static void editor2font(pcb_board_t *pcb, rnd_font_t *font)
 		ox = (s % 16 + 1) * CELL_SIZE;
 		g = &font->glyph[s];
 
+		g->advance = x1 - ox;
+		g->advance_valid = 1;
+		if (g->advance > 10)
+			g->valid = 1;
+		if ((s == 'i') || (s == 'q'))
+			rnd_trace("delta2: %c w=%ld - %ld - %ld=%ld | adv: %ld - %ld = %ld\n", s, x1, ox, g->width, x1-ox-g->width, x1, ox, x1-ox);
+
 		x1 -= ox;
 
 		g->xdelta = x1 - g->width;
@@ -279,6 +299,22 @@ static void editor2font(pcb_board_t *pcb, rnd_font_t *font)
 			g->valid = 1;
 	}
 
+	/* copy metadata */
+	if (orig_font != NULL) {
+		rnd_font_copy_tables(font, orig_font);
+		font->kerning_tbl_valid = orig_font->kerning_tbl_valid;
+		font->entity_tbl_valid = orig_font->entity_tbl_valid;
+
+		/* these numericals are not edited graphically */
+		font->baseline = orig_font->baseline;
+		font->tab_width = orig_font->tab_width;
+		font->line_height = orig_font->line_height;
+	}
+	else {
+		rnd_message(RND_MSG_ERROR, "Original font data not available, some metadata is lost\n(kerning, entities, baseline, tab/line size)\n");
+		rnd_message(RND_MSG_INFO, "Note: this typically happens if you save to board format\nfrom the font editor and load that board later\nPlease don't do that, it can't retain metadata.\n");
+	}
+
 	rnd_font_normalize(font);
 }
 
@@ -290,7 +326,7 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	pcb_board_t *pcb = PCB_ACT_BOARD;
 	rnd_font_t *font;
-	pcb_layer_t *lfont, *lorig, *lwidth, *lgrid, *lsilk;
+	pcb_layer_t *lfont, *lorig, *lwidth, *lgrid, *lsilk, *lbaslin;
 	rnd_layergrp_id_t grp[4];
 	int l, inplace = 0;
 	const char *opt = "";
@@ -346,6 +382,9 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	lwidth = make_layer(pcb, grp[2], "Width");
 	lgrid  = make_layer(pcb, grp[3], "Grid");
 
+	if (font->baseline > 0)
+		lbaslin = make_layer(pcb, grp[3], "Baseline");
+
 	assert(pcb_layergrp_list(pcb, PCB_LYT_SILK, grp, 2) == 2);
 	make_layer(pcb, grp[0], "Silk");
 	lsilk = make_layer(pcb, grp[1], "Silk");
@@ -353,7 +392,7 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pcb_layergrp_inhibit_dec();
 
 	/* Inform the rest about the board change (layer stack, size) */
-	rnd_event(&pcb->hidlib, RND_EVENT_DESIGN_SET_CURRENT, NULL);
+	rnd_event(&pcb->hidlib, RND_EVENT_DESIGN_SET_CURRENT, "p", NULL);
 	rnd_event(&pcb->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
 
 	font2editor_new(pcb, font, lfont, lorig, lwidth, lsilk);
@@ -366,6 +405,14 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		int y = (l + 1) * CELL_SIZE;
 		pcb_line_new_merge(lgrid, 0, y, pcb->hidlib.dwg.X2, y, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
 	}
+
+	if (font->baseline > 0) {
+		for (l = 0; l <= PCB_MAX_FONTPOSITION / 16 + 1; l++) {
+			int y = (l + 1) * CELL_SIZE + font->baseline;
+			pcb_line_new_merge(lbaslin, 0, y, pcb->hidlib.dwg.X2, y, RND_MIL_TO_COORD(0.25), RND_MIL_TO_COORD(1), pcb_no_flags());
+		}
+	}
+
 	RND_ACT_IRES(0);
 	return 0;
 }
@@ -380,7 +427,7 @@ static fgw_error_t pcb_act_FontSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, FontSave, fn = argv[1].val.str);
 
-	editor2font(pcb, font);
+	editor2font(pcb, font, fontedit_src);
 	rnd_actionva(RND_ACT_DESIGN, "SaveFontTo", fn, NULL);
 
 	RND_ACT_IRES(0);
@@ -589,11 +636,12 @@ static void font_set_xdelta(pcb_board_t *pcb, rnd_coord_t xd)
 	arclist_foreach(&lfont->Arc, &it, a) {
 		int cx = (a->BoundingBox.X1 + a->BoundingBox.X2)/2;
 		int cy = (a->BoundingBox.Y1 + a->BoundingBox.Y2)/2;
+		rnd_box_t bbx = pcb_arc_bbox_cline(a);
 
 		s = XYtoSym(cx, cy);
 		ox = (s % 16 + 1) * CELL_SIZE;
 
-		gw[s] = RND_MAX(gw[s], rnd_round(a->bbox_naked.X2 - ox - a->Thickness/2));
+		gw[s] = RND_MAX(gw[s], rnd_round(bbx.X2 - ox));
 	}
 
 	/* pick up polygons */
@@ -645,18 +693,38 @@ static fgw_error_t pcb_act_FontNormalize(fgw_arg_t *res, int argc, fgw_arg_t *ar
 	pcb_board_t *pcb = PCB_ACT_BOARD;
 	rnd_font_t *font = pcb_font(pcb, 0, 1);
 
-	editor2font(pcb, font);
+	editor2font(pcb, font, fontedit_src);
 	rnd_font_normalize(font);
 
 	return pcb_act_FontEdit(res, argc, argv);
 }
 
+static const char pcb_acts_FontBaseline[] = "FontBaseline(+-delta)";
+static const char pcb_acth_FontBaseline[] = "Change the baseline value and redraw. If there is no baseline, add baseline first.";
+static fgw_error_t pcb_act_FontBaseline(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	pcb_board_t *pcb = PCB_ACT_BOARD;
+	rnd_font_t *font = pcb_font(pcb, 0, 1);
+	rnd_coord_t delta = 0;
+
+	RND_ACT_MAY_CONVARG(1, FGW_COORD, FontBaseline, delta = fgw_coord(&argv[1]));
+
+	pcb->Changed = 0;
+	editor2font(pcb, font, fontedit_src);
+	if (font->baseline == 0)
+		font->baseline = RND_MIL_TO_COORD(50); /* default value that works with the default font */
+	font->baseline += delta;
+	return pcb_act_FontEdit(res, argc, argv);
+}
+
 rnd_action_t fontmode_action_list[] = {
 	{"FontEdit", pcb_act_FontEdit, pcb_acth_FontEdit, pcb_acts_FontEdit},
 	{"FontSave", pcb_act_FontSave, pcb_acth_FontSave, pcb_acts_FontSave},
 	{"FontXform", pcb_act_FontXform, pcb_acth_FontXform, pcb_acts_FontXform},
 	{"FontSetXdelta", pcb_act_FontSetXdelta, pcb_acth_FontSetXdelta, pcb_acts_FontSetXdelta},
-	{"FontNormalize", pcb_act_FontNormalize, pcb_acth_FontNormalize, pcb_acts_FontNormalize}
+	{"FontNormalize", pcb_act_FontNormalize, pcb_acth_FontNormalize, pcb_acts_FontNormalize},
+	{"FontBaseline", pcb_act_FontBaseline, pcb_acth_FontBaseline, pcb_acts_FontBaseline},
+	{"FontModePreview", pcb_act_FontModePreview, pcb_acth_FontModePreview, pcb_acts_FontModePreview}
 };
 
 static const char *fontmode_cookie = "fontmode plugin";
