@@ -1352,6 +1352,7 @@ static int eagle_read_package(read_state_t *st, trnode_t *n)
 	if (st->pcb == NULL)
 		st->fp_data = subc->data;
 
+	pcb_subc_cache_find_aux(subc);
 	pcb_attribute_put(&subc->Attributes, "refdes", "K1");
 
 	if (st->pcb != NULL) {
@@ -1383,8 +1384,8 @@ static int eagle_read_package(read_state_t *st, trnode_t *n)
 TODO("subc: revise this: are we loading an instance here? do we need to place it? do not even bump if not!")
 	if (st->pcb != NULL) {
 		if (st->pcb->Data->subc_tree == NULL)
-			st->pcb->Data->subc_tree = rnd_r_create_tree();
-		rnd_r_insert_entry(st->pcb->Data->subc_tree, (rnd_box_t *)subc);
+			rnd_rtree_init(st->pcb->Data->subc_tree = malloc(sizeof(rnd_rtree_t)));
+		rnd_rtree_insert(st->pcb->Data->subc_tree, subc, (rnd_rtree_box_t *)subc);
 		pcb_subc_rebind(st->pcb, subc);
 	}
 
@@ -1434,6 +1435,7 @@ static int eagle_read_lib_pkgs(read_state_t *st, trnode_t *subtree, void *obj, i
 			}
 
 			subc = pcb_subc_alloc();
+			pcb_subc_cache_find_aux(subc);
 			eagle_read_pkg(st, n, subc);
 			if (pcb_subc_is_empty(subc)) {
 				rnd_message(RND_MSG_WARNING, "Ignoring empty package %s\n", name);
