@@ -4,7 +4,7 @@
 #include <genht/hash.h>
 #include "config.h"
 #include "uniq_name.h"
-#include "compat_misc.h"
+#include <librnd/core/compat_misc.h>
 
 static const char *unm_default_unnamed = "unnamed";
 static const char *unm_default_suffix_sep = "_dup";
@@ -36,7 +36,7 @@ const char *unm_name(unm_t *state, const char *orig_name, void *user_data)
 
 	if ((orig_name == NULL) || (*orig_name == '\0')) {
 		if (!htsp_has(&state->seen, (char *)state->unnamed)) {
-			name = pcb_strdup(state->unnamed);
+			name = rnd_strdup(state->unnamed);
 			htsp_set(&state->seen, name, user_data);
 			return name;
 		}
@@ -46,7 +46,7 @@ const char *unm_name(unm_t *state, const char *orig_name, void *user_data)
 	}
 	else {
 		if (!htsp_has(&state->seen, (char *)orig_name)) {
-			name = pcb_strdup(orig_name);
+			name = rnd_strdup(orig_name);
 			htsp_set(&state->seen, name, user_data);
 			return name;
 		}
