@@ -34,7 +34,8 @@ int io_lihata_write_pcb_v5(pcb_plug_io_t *ctx, FILE *FP, const char *old_filenam
 int io_lihata_write_pcb_v6(pcb_plug_io_t *ctx, FILE *FP, const char *old_filename, const char *new_filename, rnd_bool emergency);
 int io_lihata_write_pcb_v7(pcb_plug_io_t *ctx, FILE *FP, const char *old_filename, const char *new_filename, rnd_bool emergency);
 int io_lihata_write_pcb_v8(pcb_plug_io_t *ctx, FILE *FP, const char *old_filename, const char *new_filename, rnd_bool emergency);
-int io_lihata_write_font(pcb_plug_io_t *ctx, rnd_font_t *font, const char *Filename);
+int io_lihata_write_pcb_v9(pcb_plug_io_t *ctx, FILE *FP, const char *old_filename, const char *new_filename, rnd_bool emergency);
+int io_lihata_write_font(pcb_plug_io_t *ctx, rnd_font_t *font, const char *Filename, const char *fmt);
 int io_lihata_write_buffer(pcb_plug_io_t *ctx, FILE *f, pcb_buffer_t *buff);
 int io_lihata_write_subcs_head(pcb_plug_io_t *ctx, void **udata, FILE *f, int lib, long num_subcs);
 int io_lihata_write_subcs_subc(pcb_plug_io_t *ctx, void **udata, FILE *f, pcb_subc_t *subc);
