@@ -38,11 +38,11 @@
 #include "conf_core.h"
 #include "buffer.h"
 #include <librnd/core/plugins.h>
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
-#include <librnd/core/hid_menu.h>
+#include <librnd/hid/hid_menu.h>
 #include "plug_io.h"
 #include "stackup.h"
 #include "tlayer.h"
@@ -227,7 +227,7 @@ static fgw_error_t pcb_act_TedaxTestParse(fgw_arg_t *res, int argc, fgw_arg_t *a
 	if (argc < 2)
 		return -1;
 	if ((argv[1].type & FGW_STR) == FGW_STR) {
-		FILE *f = rnd_fopen(RND_ACT_HIDLIB, argv[1].val.str, "r");
+		FILE *f = rnd_fopen(RND_ACT_DESIGN, argv[1].val.str, "r");
 		if (f == NULL) {
 			RND_ACT_IRES(0);
 			return 0;
