@@ -33,7 +33,8 @@ pcb_pstk_t *pcb_pstk_new_compat_pad(pcb_data_t *data, long int id, rnd_coord_t x
 rnd_bool pcb_pstk_export_compat_pad(pcb_pstk_t *ps, rnd_coord_t *x1, rnd_coord_t *y1, rnd_coord_t *x2, rnd_coord_t *y2, rnd_coord_t *thickness, rnd_coord_t *clearance, rnd_coord_t *mask, rnd_bool *square, rnd_bool *nopaste);
 
 typedef enum {
-	PCB_PSTKCOMP_OLD_OCTAGON = 1
+	PCB_PSTKCOMP_OLD_OCTAGON = 1,
+	PCB_PSTKCOMP_PCB_CLEARLINE_WORKAROUND = 2
 } pcb_pstk_compat_t;
 
 /* Convert padstack flags to old pin/via flag. Use only in gEDA/PCB
@@ -46,7 +47,8 @@ pcb_flag_t pcb_pstk_compat_pinvia_flag(pcb_pstk_t *ps, pcb_pstk_compshape_t csha
    If id <= 0, allocate a new ID automatically.
    Should not be used anywhere but io_pcb and io_lihata. */
 pcb_pstk_t *pcb_old_via_new(pcb_data_t *data, long int id, rnd_coord_t X, rnd_coord_t Y, rnd_coord_t Thickness, rnd_coord_t Clearance, rnd_coord_t Mask, rnd_coord_t DrillingHole, const char *Name, pcb_flag_t Flags);
-
+pcb_pstk_t *pcb_old_via_new_bbvia(pcb_data_t *data, long int id, rnd_coord_t X, rnd_coord_t Y, rnd_coord_t Thickness, rnd_coord_t Clearance, rnd_coord_t Mask, rnd_coord_t DrillingHole, const char *Name, pcb_flag_t Flags, int htop, int hbottom);
+extern int compat_pstk_cop_grps; /* ugly hack for io_pcb to communicate number of copper layers to bbvia offseting */
 
 
 /*** low level ***/
