@@ -29,9 +29,9 @@
 #include <genvector/vti0.h>
 #include <genvector/vtp0.h>
 
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include <librnd/core/hid_cfg.h>
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 #include <librnd/plugins/lib_hid_common/xpm.h>
 
 #include <librnd/core/actions.h>
@@ -42,7 +42,7 @@
 #include "layer_grp.h"
 #include "layer_ui.h"
 #include "layer_vis.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include "layersel.h"
 
@@ -286,7 +286,7 @@ static void layer_select(ls_layer_t *lys)
 	else
 		return;
 
-	rnd_hid_redraw(PCB);
+	rnd_hid_redraw(&PCB->hidlib);
 
 	if (vis != NULL) {
 		lys_update_vis(lys, *vis);
@@ -349,12 +349,12 @@ static void all_close_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 
 static void all_vis_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
-	rnd_actionva(rnd_gui->get_dad_hidlib(hid_ctx), "ToggleView", "all", "vis", "set", NULL);
+	rnd_actionva(rnd_gui->get_dad_design(hid_ctx), "ToggleView", "all", "vis", "set", NULL);
 }
 
 static void all_invis_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
-	rnd_actionva(rnd_gui->get_dad_hidlib(hid_ctx), "ToggleView", "all", "vis", "clear", NULL);
+	rnd_actionva(rnd_gui->get_dad_design(hid_ctx), "ToggleView", "all", "vis", "clear", NULL);
 }
 
 /* Select the first visible layer (physically) below the one turned off or
@@ -434,7 +434,7 @@ static void layer_vis_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 
 	ensure_visible_current(PCB, lys->ls);
 
-	rnd_hid_redraw(PCB);
+	rnd_hid_redraw(&PCB->hidlib);
 }
 
 static void layer_right_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -864,13 +864,13 @@ static void layersel_build(void)
 	}
 }
 
-void pcb_layersel_gui_init_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+void pcb_layersel_gui_init_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if ((RND_HAVE_GUI_ATTR_DLG) && (rnd_gui->get_menu_cfg != NULL))
 		layersel_build();
 }
 
-void pcb_layersel_vis_chg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+void pcb_layersel_vis_chg_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	pcb_board_t *pcb = (pcb_board_t *)hidlib;
 	if ((!layersel.sub_inited) || (layersel.lock_vis > 0))
@@ -878,7 +878,7 @@ void pcb_layersel_vis_chg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rn
 	layersel_update_vis(&layersel, pcb);
 }
 
-void pcb_layersel_stack_chg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+void pcb_layersel_stack_chg_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if ((RND_HAVE_GUI_ATTR_DLG) && (rnd_gui->get_menu_cfg != NULL) && (layersel.sub_inited)) {
 		rnd_hid_dock_leave(&layersel.sub);
