@@ -93,7 +93,7 @@ void pplg_uninit_lib_hid_pcbui(void)
 	rnd_toolbar_uninit();
 }
 
-static rnd_conf_hid_id_t install_events(const char *cookie, const char *paths[], rnd_conf_hid_callbacks_t cb[], void (*update_cb)(rnd_conf_native_t*,int))
+static rnd_conf_hid_id_t install_events(const char *cookie, const char *paths[], rnd_conf_hid_callbacks_t cb[], void (*update_cb)(rnd_conf_native_t*,int,void*))
 {
 	const char **rp;
 	rnd_conf_native_t *nat;
@@ -129,27 +129,27 @@ int pplg_init_lib_hid_pcbui(void)
 	RND_REGISTER_ACTIONS(status_action_list, status_cookie);
 	RND_REGISTER_ACTIONS(act_action_list, act_cookie);
 
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, pcb_layer_menu_update_ev, NULL, layer_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, pcb_layer_menu_update_ev, NULL, layer_cookie);
 	rnd_event_bind(PCB_EVENT_LAYERS_CHANGED, pcb_layer_menu_update_ev, NULL, layer_cookie);
 	rnd_event_bind(PCB_EVENT_LAYERS_CHANGED, pcb_layersel_stack_chg_ev, NULL, layersel_cookie);
 	rnd_event_bind(PCB_EVENT_LAYERVIS_CHANGED, pcb_layer_menu_vis_update_ev, NULL, layer_cookie);
 	rnd_event_bind(PCB_EVENT_LAYERVIS_CHANGED, pcb_layersel_vis_chg_ev, NULL, layersel_cookie);
 	rnd_event_bind(PCB_EVENT_LAYER_KEY_CHANGE, pcb_layer_menu_key_update_ev, NULL, layer_cookie);
 	rnd_event_bind(PCB_EVENT_ROUTE_STYLES_CHANGED, pcb_rst_update_ev, NULL, rst_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, pcb_rst_update_ev, NULL, rst_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, pcb_rst_update_ev, NULL, rst_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, pcb_rst_gui_init_ev, NULL, rst_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, pcb_layersel_gui_init_ev, NULL, layersel_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, pcb_status_gui_init_ev, NULL, status_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, pcb_rendering_gui_init_ev, NULL, rendering_cookie);
 	rnd_event_bind(RND_EVENT_USER_INPUT_KEY, pcb_status_st_update_ev, NULL, status_cookie);
 	rnd_event_bind(RND_EVENT_CROSSHAIR_MOVE, pcb_status_rd_update_ev, NULL, status_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, pcb_infobar_brdchg_ev, NULL, infobar_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_FN_CHANGED, pcb_infobar_fn_chg_ev, NULL, infobar_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, pcb_infobar_brdchg_ev, NULL, infobar_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_FN_CHANGED, pcb_infobar_fn_chg_ev, NULL, infobar_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, pcb_infobar_gui_init_ev, NULL, infobar_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, pcb_title_gui_init_ev, NULL, title_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, pcb_title_board_changed_ev, NULL, title_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_FN_CHANGED, pcb_title_board_changed_ev, NULL, title_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_META_CHANGED, pcb_title_meta_changed_ev, NULL, title_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, pcb_title_board_changed_ev, NULL, title_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_FN_CHANGED, pcb_title_board_changed_ev, NULL, title_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_META_CHANGED, pcb_title_meta_changed_ev, NULL, title_cookie);
 	rnd_event_bind(RND_EVENT_GUI_BATCH_TIMER, pcb_layer_menu_batch_timer_ev, NULL, layer_cookie);
 	rnd_event_bind(RND_EVENT_GUI_BATCH_TIMER, pcb_rst_menu_batch_timer_ev, NULL, rst_cookie);
 
