@@ -272,12 +272,13 @@ static int rst_edit_attr(char **key, char **val)
 				wval = RND_DAD_CURRENT(dlg);
 				if (*val != NULL)
 					RND_DAD_DEFAULT_PTR(dlg, rnd_strdup(*val));
+		RND_DAD_END(dlg);
 		RND_DAD_BUTTON_CLOSES(dlg, clbtn);
 	RND_DAD_END(dlg);
 
 	RND_DAD_NEW("route_style_attr", dlg, "Edit route style attribute", NULL, rnd_true, NULL);
 	res = RND_DAD_RUN(dlg);
-	if (res == 0) {
+	if ((res == 0) && (dlg[wkey].val.str != NULL) && (dlg[wval].val.str != NULL)) {
 		*key = rnd_strdup(dlg[wkey].val.str);
 		*val = rnd_strdup(dlg[wval].val.str);
 	}
