@@ -55,6 +55,7 @@
 #include "ewire_point.h"
 #include "pointdata.h"
 #include "spoke.h"
+#define CDT_INLINE RND_INLINE
 #include <libcdtr/cdt.h>
 #include <genht/htip.h>
 #include <genht/htpp.h>
@@ -91,8 +92,11 @@ static void sketch_update_cdt_layer(sketch_t *sk)
 	pcb_layer_t *l = sk->ui_layer_cdt;
 
 	list_map0(&l->Line, pcb_line_t, pcb_line_free);
-	if (l->line_tree)
-		rnd_r_destroy_tree(&l->line_tree);
+	if (l->line_tree) {
+		rnd_rtree_uninit(l->line_tree);
+		free(l->line_tree);
+		l->line_tree = NULL;
+	}
 	VTEDGE_FOREACH(e, &sk->cdt->edges)
 		pcb_line_new(l, e->endp[0]->pos.x, -e->endp[0]->pos.y, e->endp[1]->pos.x, -e->endp[1]->pos.y, 1, 0, pcb_no_flags());
 	VTEDGE_FOREACH_END();
@@ -105,8 +109,11 @@ static void sketch_update_erbs_layer(sketch_t *sk)
 	int i;
 
 	list_map0(&l->Line, pcb_line_t, pcb_line_free);
-	if (l->line_tree)
-		rnd_r_destroy_tree(&l->line_tree);
+	if (l->line_tree) {
+		rnd_rtree_uninit(l->line_tree);
+		free(l->line_tree);
+		l->line_tree = NULL;
+	}
 
 	VTEWIRE_FOREACH(ew, &sk->ewires)
 		ewire_point_t *ewp = &ew->points.array[0];
@@ -653,16 +660,16 @@ struct search_info {
 	sketch_t *sk;
 };
 
-static rnd_r_dir_t r_search_cb(const rnd_box_t *box, void *cl)
+static rnd_rtree_dir_t r_search_cb(void *cl, void *obj_, const rnd_rtree_box_t *box)
 {
-	pcb_any_obj_t *obj = (pcb_any_obj_t *) box;
+	pcb_any_obj_t *obj = (pcb_any_obj_t *)obj_;
 	struct search_info *i = (struct search_info *) cl;
 	point_t *point;
 
 	if (obj->type == PCB_OBJ_PSTK) {
 		pcb_pstk_t *pstk = (pcb_pstk_t *) obj;
 		if (pcb_pstk_shape_at(PCB, pstk, i->layer) == NULL)
-			return RND_R_DIR_NOT_FOUND;
+			return rnd_RTREE_DIR_NOT_FOUND_CONT;
 		point = cdt_insert_point(i->sk->cdt, pstk->x, -pstk->y);
 		pointdata_create(point, obj);
 	}
@@ -685,7 +692,7 @@ static rnd_r_dir_t r_search_cb(const rnd_box_t *box, void *cl)
 			htpp_insert(&i->sk->terminals, obj, point);
 	}
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
 static void sketch_create_for_layer(sketch_t *sk, pcb_layer_t *layer)
@@ -706,16 +713,16 @@ static void sketch_create_for_layer(sketch_t *sk, pcb_layer_t *layer)
 	sk->ewires.elem_copy = NULL;
 	vtewire_init(&sk->ewires);
 
-	sk->spoke_tree = rnd_r_create_tree();
+	rnd_rtree_init(sk->spoke_tree = malloc(sizeof(rnd_rtree_t)));
 
 	bbox.X1 = PCB->hidlib.dwg.X1; bbox.Y1 = PCB->hidlib.dwg.Y1; bbox.X2 = PCB->hidlib.dwg.X2; bbox.Y2 = PCB->hidlib.dwg.Y2;
 	info.layer = layer;
 	info.sk = sk;
-	rnd_r_search(PCB->Data->padstack_tree, &bbox, NULL, r_search_cb, &info, NULL);
-	rnd_r_search(layer->line_tree, &bbox, NULL, r_search_cb, &info, NULL);
-	rnd_r_search(layer->text_tree, &bbox, NULL, r_search_cb, &info, NULL);
-	rnd_r_search(layer->polygon_tree, &bbox, NULL, r_search_cb, &info, NULL);
-	rnd_r_search(layer->arc_tree, &bbox, NULL, r_search_cb, &info, NULL);
+	rnd_rtree_search_any(PCB->Data->padstack_tree, (rnd_rtree_box_t *)&bbox, NULL, r_search_cb, &info, NULL);
+	rnd_rtree_search_any(layer->line_tree, (rnd_rtree_box_t *)&bbox, NULL, r_search_cb, &info, NULL);
+	rnd_rtree_search_any(layer->text_tree, (rnd_rtree_box_t *)&bbox, NULL, r_search_cb, &info, NULL);
+	rnd_rtree_search_any(layer->polygon_tree, (rnd_rtree_box_t *)&bbox, NULL, r_search_cb, &info, NULL);
+	rnd_rtree_search_any(layer->arc_tree, (rnd_rtree_box_t *)&bbox, NULL, r_search_cb, &info, NULL);
 
 	rnd_snprintf(name, sizeof(name), "%s: CDT", layer->name);
 	sk->ui_layer_cdt = pcb_uilayer_alloc(PCB, pcb_sketch_route_cookie, name, &layer->meta.real.color);
@@ -748,7 +755,11 @@ static void sketch_uninit(sketch_t *sk)
 	vtwire_uninit(&sk->wires);
 	vtewire_uninit(&sk->ewires);
 	htpp_uninit(&sk->terminals);
-	rnd_r_destroy_tree(&sk->spoke_tree);
+
+	rnd_rtree_uninit(sk->spoke_tree);
+	free(sk->spoke_tree);
+	sk->spoke_tree = NULL;
+
 	pcb_uilayer_free(sk->ui_layer_cdt);
 	pcb_uilayer_free(sk->ui_layer_erbs);
 }
