@@ -40,7 +40,7 @@
 #include <librnd/core/actions.h>
 #include "polygon.h"
 #include "search.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 
 
 void pcb_tool_polyhole_uninit(void)
@@ -51,7 +51,7 @@ void pcb_tool_polyhole_uninit(void)
 	rnd_hid_notify_crosshair_change(&PCB->hidlib, rnd_true);
 }
 
-void pcb_tool_polyhole_notify_mode(rnd_hidlib_t *hl)
+void pcb_tool_polyhole_notify_mode(rnd_design_t *hl)
 {
 	switch (pcb_crosshair.AttachedObject.State) {
 		/* first notify, lookup object */
@@ -127,7 +127,7 @@ void pcb_tool_polyhole_notify_mode(rnd_hidlib_t *hl)
 	}
 }
 
-void pcb_tool_polyhole_adjust_attached_objects(rnd_hidlib_t *hl)
+void pcb_tool_polyhole_adjust_attached_objects(rnd_design_t *hl)
 {
 	pcb_attached_line_t *line = &pcb_crosshair.AttachedLine;
 
@@ -146,7 +146,7 @@ void pcb_tool_polyhole_adjust_attached_objects(rnd_hidlib_t *hl)
 	pcb_line_45(line);
 }
 
-void pcb_tool_polyhole_draw_attached(rnd_hidlib_t *hl)
+void pcb_tool_polyhole_draw_attached(rnd_design_t *hl)
 {
 	/* draw only if starting point is set */
 	if (pcb_crosshair.AttachedLine.State != PCB_CH_STATE_FIRST)
@@ -160,7 +160,7 @@ void pcb_tool_polyhole_draw_attached(rnd_hidlib_t *hl)
 	}
 }
 
-rnd_bool pcb_tool_polyhole_undo_act(rnd_hidlib_t *hl)
+rnd_bool pcb_tool_polyhole_undo_act(rnd_design_t *hl)
 {
 	if (pcb_crosshair.AttachedPolygon.PointN) {
 		pcb_polygon_go_to_prev_point();
@@ -169,7 +169,7 @@ rnd_bool pcb_tool_polyhole_undo_act(rnd_hidlib_t *hl)
 	return rnd_true;
 }
 
-rnd_bool pcb_tool_polyhole_redo_act(rnd_hidlib_t *hl)
+rnd_bool pcb_tool_polyhole_redo_act(rnd_design_t *hl)
 {
 	if (pcb_crosshair.AttachedPolygon.PointN) {
 		pcb_polygon_go_to_next_point();
@@ -179,7 +179,7 @@ rnd_bool pcb_tool_polyhole_redo_act(rnd_hidlib_t *hl)
 		return rnd_true;
 }
 
-void pcb_tool_polyhole_escape(rnd_hidlib_t *hl)
+void pcb_tool_polyhole_escape(rnd_design_t *hl)
 {
 	if (pcb_crosshair.AttachedLine.State == PCB_CH_STATE_FIRST)
 		rnd_tool_select_by_name(hl, "arrow");
