@@ -41,12 +41,12 @@
 #include "remove.h"
 #include "search.h"
 #include "obj_rat.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include "crosshair.h"
 #include "tool_logic.h"
 
 
-void pcb_tool_remove_notify_mode(rnd_hidlib_t *hl)
+void pcb_tool_remove_notify_mode(rnd_design_t *hl)
 {
 	pcb_board_t *pcb = (pcb_board_t *)hl;
 	void *ptr1, *ptr2, *ptr3;
