@@ -38,12 +38,12 @@
 #include <librnd/core/actions.h>
 #include "board.h"
 #include "rotate.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include "crosshair.h"
 #include "tool_logic.h"
 
 
-void pcb_tool_rotate_notify_mode(rnd_hidlib_t *hl)
+void pcb_tool_rotate_notify_mode(rnd_design_t *hl)
 {
 	pcb_screen_obj_rotate90((pcb_board_t *)hl, hl->tool_x, hl->tool_y,
 		rnd_gui->shift_is_pressed(rnd_gui) ? (conf_core.editor.show_solder_side ? 1 : 3) : (conf_core.editor.show_solder_side ? 3 : 1));
