@@ -35,20 +35,20 @@
 #include "config.h"
 
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include "board.h"
 #include "change.h"
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include "data.h"
 #include "draw.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include "tool_thermal.h"
 #include "undo.h"
 
 #include "obj_pstk_draw.h"
 
-void pcb_tool_via_notify_mode(rnd_hidlib_t *hl)
+void pcb_tool_via_notify_mode(rnd_design_t *hl)
 {
 	pcb_board_t *pcb = (pcb_board_t *)hl;
 	pcb_pstk_t *ps;
@@ -76,7 +76,7 @@ void pcb_tool_via_notify_mode(rnd_hidlib_t *hl)
 }
 
 
-void pcb_tool_via_draw_attached(rnd_hidlib_t *hl)
+void pcb_tool_via_draw_attached(rnd_design_t *hl)
 {
 		static pcb_pstk_t ps; /* initialized to all-zero */
 
